Serialized Form


Package com.hazelcast.cluster

Class com.hazelcast.cluster.AbstractRemotelyCallable extends AbstractNodeAware implements Serializable

Serialized Fields

conn

Connection conn

Class com.hazelcast.cluster.AbstractRemotelyProcessable extends AbstractNodeAware implements Serializable

Serialized Fields

conn

Connection conn

Class com.hazelcast.cluster.AddOrRemoveConnection extends AbstractRemotelyProcessable implements Serializable

Serialized Fields

address

Address address

add

boolean add

Class com.hazelcast.cluster.Bind extends Master implements Serializable

Class com.hazelcast.cluster.ClusterManager.RemoveMember extends Object implements Serializable

Serialized Fields

deadAddress

Address deadAddress

Class com.hazelcast.cluster.ConnectionCheckCall extends AbstractRemotelyCallable<Boolean> implements Serializable

Class com.hazelcast.cluster.FinalizeJoin extends AbstractRemotelyCallable<Boolean> implements Serializable

Class com.hazelcast.cluster.InitialProcess extends AbstractRemotelyProcessable implements Serializable

serialVersionUID: 4803635299019880729L

Serialized Fields

processables

List<E> processables

Class com.hazelcast.cluster.JoinInfo extends JoinRequest implements Serializable

Serialized Fields

request

boolean request

memberCount

int memberCount

Class com.hazelcast.cluster.JoinRequest extends AbstractRemotelyProcessable implements Serializable

Serialized Fields

nodeType

NodeType nodeType

address

Address address

to

Address to

packetVersion

byte packetVersion

buildNumber

int buildNumber

config

Config config

Class com.hazelcast.cluster.Master extends AbstractRemotelyProcessable implements Serializable

Serialized Fields

address

Address address
The address.

Class com.hazelcast.cluster.MemberInfo extends Object implements Serializable

Serialized Fields

address

Address address

nodeType

NodeType nodeType

Class com.hazelcast.cluster.MemberRemover extends AbstractRemotelyProcessable implements Serializable

Serialized Fields

deadAddress

Address deadAddress

Class com.hazelcast.cluster.MembersUpdateCall extends AbstractRemotelyCallable<Boolean> implements Serializable

serialVersionUID: -2311579721761844861L

Serialized Fields

memberInfos

Collection<E> memberInfos

masterTime

long masterTime

Class com.hazelcast.cluster.SyncProcess extends AbstractRemotelyCallable<Boolean> implements Serializable

Serialized Fields

connection

Connection connection

Package com.hazelcast.config

Class com.hazelcast.config.AsymmetricEncryptionConfig extends Object implements Serializable

Serialized Fields

enabled

boolean enabled

algorithm

String algorithm

keyPassword

String keyPassword

keyAlias

String keyAlias

storeType

String storeType

storePassword

String storePassword

storePath

String storePath

Class com.hazelcast.config.ClasspathXmlConfig extends Config implements Serializable

Serialized Fields

logger

ILogger logger

Class com.hazelcast.config.Config extends Object implements Serializable

Serialized Fields

xmlConfig

String xmlConfig

groupConfig

GroupConfig groupConfig

port

int port

checkCompatibility

boolean checkCompatibility

reuseAddress

boolean reuseAddress

portAutoIncrement

boolean portAutoIncrement

executorConfig

ExecutorConfig executorConfig

mapExecutors

Map<K,V> mapExecutors

mapTopicConfigs

Map<K,V> mapTopicConfigs

mapQueueConfigs

Map<K,V> mapQueueConfigs

mapConfigs

Map<K,V> mapConfigs

configurationUrl

URL configurationUrl

configurationFile

File configurationFile

networkConfig

NetworkConfig networkConfig

superClient

boolean superClient

classLoader

ClassLoader classLoader

properties

Properties properties

mapMergePolicyConfigs

Map<K,V> mapMergePolicyConfigs

Class com.hazelcast.config.ExecutorConfig extends Object implements Serializable

Serialized Fields

name

String name

corePoolSize

int corePoolSize

maxPoolSize

int maxPoolSize

keepAliveSeconds

int keepAliveSeconds

Class com.hazelcast.config.FileSystemXmlConfig extends Config implements Serializable

Serialized Fields

logger

ILogger logger

Class com.hazelcast.config.GroupConfig extends Object implements Serializable

Serialized Fields

name

String name

password

String password

Class com.hazelcast.config.InMemoryXmlConfig extends Config implements Serializable

Serialized Fields

logger

ILogger logger

Class com.hazelcast.config.Interfaces extends Object implements Serializable

Serialized Fields

enabled

boolean enabled

interfaceSet

Set<E> interfaceSet

Class com.hazelcast.config.Join extends Object implements Serializable

Serialized Fields

multicastConfig

MulticastConfig multicastConfig

tcpIpConfig

TcpIpConfig tcpIpConfig

Class com.hazelcast.config.MapConfig extends Object implements Serializable

Serialized Fields

name

String name

backupCount

int backupCount

evictionPercentage

int evictionPercentage

timeToLiveSeconds

int timeToLiveSeconds

maxIdleSeconds

int maxIdleSeconds

evictionDelaySeconds

int evictionDelaySeconds

maxSizeConfig

MaxSizeConfig maxSizeConfig

evictionPolicy

String evictionPolicy

valueIndexed

boolean valueIndexed

mapStoreConfig

MapStoreConfig mapStoreConfig

nearCacheConfig

NearCacheConfig nearCacheConfig

readBackupData

boolean readBackupData

cacheValue

boolean cacheValue

mergePolicy

String mergePolicy

Class com.hazelcast.config.MaxSizeConfig extends Object implements Serializable

Serialized Fields

size

int size

maxSizePolicy

String maxSizePolicy

Class com.hazelcast.config.MulticastConfig extends Object implements Serializable

Serialized Fields

enabled

boolean enabled

multicastGroup

String multicastGroup

multicastPort

int multicastPort

multicastTimeoutSeconds

int multicastTimeoutSeconds

Class com.hazelcast.config.NetworkConfig extends Object implements Serializable

Serialized Fields

interfaces

Interfaces interfaces

join

Join join

symmetricEncryptionConfig

SymmetricEncryptionConfig symmetricEncryptionConfig

asymmetricEncryptionConfig

AsymmetricEncryptionConfig asymmetricEncryptionConfig

Class com.hazelcast.config.QueueConfig extends Object implements Serializable

Serialized Fields

name

String name

backingMapRef

String backingMapRef

maxSizePerJVM

int maxSizePerJVM

Class com.hazelcast.config.SymmetricEncryptionConfig extends Object implements Serializable

Serialized Fields

enabled

boolean enabled

salt

String salt

password

String password

iterationCount

int iterationCount

algorithm

String algorithm

key

byte[] key

Class com.hazelcast.config.TcpIpConfig extends Object implements Serializable

Serialized Fields

connectionTimeoutSeconds

int connectionTimeoutSeconds

enabled

boolean enabled

members

List<E> members

requiredMember

String requiredMember

addresses

List<E> addresses

Class com.hazelcast.config.TopicConfig extends Object implements Serializable

Serialized Fields

name

String name

globalOrderingEnabled

boolean globalOrderingEnabled

Class com.hazelcast.config.UrlXmlConfig extends Config implements Serializable

Serialized Fields

logger

ILogger logger

Package com.hazelcast.core

Class com.hazelcast.core.DistributedTask.DistributedRunnableAdapterImpl extends Object implements Serializable

serialVersionUID: -4L

Serialized Fields

task

Runnable task

result

Object result

Class com.hazelcast.core.EntryEvent extends EventObject implements Serializable

serialVersionUID: -2296203982913729851L

Serialized Fields

entryEventType

EntryEventType entryEventType

key

Object key

oldValue

Object oldValue

value

Object value

member

Member member

name

String name

collection

boolean collection

Class com.hazelcast.core.HazelcastInstanceAwareObject extends Object implements Serializable

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream out)
                  throws IOException
Throws:
IOException

Class com.hazelcast.core.InstanceEvent extends EventObject implements Serializable

Serialized Fields

instanceEventType

InstanceEvent.InstanceEventType instanceEventType

instance

Instance instance

Class com.hazelcast.core.MemberLeftException extends ExecutionException implements Serializable

Serialized Fields

member

Member member

Class com.hazelcast.core.MembershipEvent extends EventObject implements Serializable

serialVersionUID: -2010865371829087371L

Serialized Fields

member

Member member

eventType

int eventType

Package com.hazelcast.examples

Class com.hazelcast.examples.AllTest.Customer extends Object implements Serializable

Serialized Fields

year

int year

name

String name

field

byte[] field

Class com.hazelcast.examples.TestApp.Echo extends HazelcastInstanceAwareObject implements Serializable

Serialized Fields

input

String input

Class com.hazelcast.examples.TestApp.LongTask extends HazelcastInstanceAwareObject implements Serializable

Serialized Fields

input

String input

Package com.hazelcast.impl

Class com.hazelcast.impl.AtomicNumberImpl extends com.hazelcast.impl.base.FactoryAwareNamedProxy implements Serializable

Serialized Fields

base

AtomicNumber base

nameAsData

Data nameAsData

Class com.hazelcast.impl.Block extends Object implements Serializable

Serialized Fields

blockId

int blockId

owner

Address owner

migrationAddress

Address migrationAddress

hash

int hash

migrationStarted

boolean migrationStarted

Class com.hazelcast.impl.BlockingQueueManager.GetValueKeysCallable extends Object implements Serializable

Serialized Fields

hazelcast

HazelcastInstance hazelcast

item

Data item

name

String name

Class com.hazelcast.impl.Blocks extends AbstractRemotelyProcessable implements Serializable

Serialized Fields

lsBlocks

List<E> lsBlocks

Class com.hazelcast.impl.ClientDistributedTask extends Object implements Serializable

Serialized Fields

callable

Callable<V> callable

member

Member member

members

Set<E> members

key

Object key

Class com.hazelcast.impl.ClientService.PartitionImpl extends Object implements Serializable

Serialized Fields

partitionId

int partitionId

owner

MemberImpl owner

Class com.hazelcast.impl.ClientServiceException extends Object implements Serializable

Serialized Fields

throwable

Throwable throwable

Class com.hazelcast.impl.CMap.CMapEntry extends Object implements Serializable

Serialized Fields

cost

long cost

expirationTime

long expirationTime

lastAccessTime

long lastAccessTime

lastUpdateTime

long lastUpdateTime

lastStoredTime

long lastStoredTime

creationTime

long creationTime

version

long version

hits

int hits

valid

boolean valid

name

String name

key

Object key

value

Object value

hazelcastInstance

HazelcastInstance hazelcastInstance

Class com.hazelcast.impl.CMap.Values extends Object implements Serializable

Serialized Fields

lsValues

Collection<E> lsValues

Class com.hazelcast.impl.ConcurrentMapManager.GetAllCallable extends Object implements Serializable

Serialized Fields

mapName

String mapName

keys

Keys keys

factory

FactoryImpl factory

Class com.hazelcast.impl.ConcurrentMapManager.PutAllCallable extends Object implements Serializable

Serialized Fields

mapName

String mapName

pairs

com.hazelcast.impl.base.Pairs pairs

factory

FactoryImpl factory

Class com.hazelcast.impl.DataAwareEntryEvent extends EntryEvent implements Serializable

Serialized Fields

dataKey

Data dataKey

dataNewValue

Data dataNewValue

dataOldValue

Data dataOldValue

Class com.hazelcast.impl.EvictLocalMapEntriesCallable extends Object implements Serializable

serialVersionUID: -8809741591882405286L

Serialized Fields

mapName

String mapName

percentage

int percentage

Class com.hazelcast.impl.FactoryImpl.CollectionProxyImpl extends BaseCollection implements Serializable

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream out)
                  throws IOException
Throws:
IOException
Serialized Fields

name

String name

Class com.hazelcast.impl.FactoryImpl.HazelcastInstanceProxy extends HazelcastInstanceAwareObject implements Serializable

Class com.hazelcast.impl.FactoryImpl.IdGeneratorProxy extends com.hazelcast.impl.base.FactoryAwareNamedProxy implements Serializable

Class com.hazelcast.impl.FactoryImpl.InitializeMap extends Object implements Serializable

Serialized Fields

name

String name

Class com.hazelcast.impl.FactoryImpl.LockProxy extends SerializationHelper implements Serializable

Serialized Fields

key

Object key

Class com.hazelcast.impl.FactoryImpl.MProxyImpl extends com.hazelcast.impl.base.FactoryAwareNamedProxy implements Serializable

Class com.hazelcast.impl.FactoryImpl.MultiMapProxyImpl extends com.hazelcast.impl.base.FactoryAwareNamedProxy implements Serializable

Class com.hazelcast.impl.FactoryImpl.ProxyKey extends SerializationHelper implements Serializable

Serialized Fields

name

String name

key

Object key

Class com.hazelcast.impl.FactoryImpl.QProxyImpl extends AbstractQueue implements Serializable

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream out)
                  throws IOException
Throws:
IOException
Serialized Fields

name

String name

blockingQueueManager

BlockingQueueManager blockingQueueManager

listenerManager

ListenerManager listenerManager

Class com.hazelcast.impl.FactoryImpl.TopicProxyImpl extends com.hazelcast.impl.base.FactoryAwareNamedProxy implements Serializable

Serialized Fields

topicManager

TopicManager topicManager

listenerManager

ListenerManager listenerManager

Class com.hazelcast.impl.Keys extends AbstractSet<Data> implements Serializable

Serialized Fields

keys

Collection<E> keys

Class com.hazelcast.impl.ListenerManager.ListenerItem extends AbstractRemotelyProcessable implements Serializable

Serialized Fields

name

String name

key

Object key

listener

Object listener

includeValue

boolean includeValue

instanceType

Instance.InstanceType instanceType

localListener

boolean localListener

Class com.hazelcast.impl.ListProxyImpl extends AbstractList implements Serializable

Serialized Fields

name

String name

factory

FactoryImpl factory

Class com.hazelcast.impl.LocalMapStatsImpl extends Object implements Serializable

Serialized Fields

lastAccessTime

AtomicLong lastAccessTime

hits

AtomicLong hits

ownedEntryCount

long ownedEntryCount

backupEntryCount

long backupEntryCount

markedAsRemovedEntryCount

long markedAsRemovedEntryCount

ownedEntryMemoryCost

long ownedEntryMemoryCost

backupEntryMemoryCost

long backupEntryMemoryCost

markedAsRemovedMemoryCost

long markedAsRemovedMemoryCost

creationTime

long creationTime

lastUpdateTime

long lastUpdateTime

lastEvictionTime

long lastEvictionTime

lockedEntryCount

long lockedEntryCount

lockWaitCount

long lockWaitCount

dirtyEntryCount

long dirtyEntryCount

operationStats

LocalMapOperationStats operationStats

Class com.hazelcast.impl.LocalQueueOperationStatsImpl extends Object implements Serializable

Serialized Fields

periodStart

long periodStart

periodEnd

long periodEnd

numberOfOffers

long numberOfOffers

numberOfRejectedOffers

long numberOfRejectedOffers

numberOfPolls

long numberOfPolls

numberOfEmptyPolls

long numberOfEmptyPolls

numberOfOtherOperations

long numberOfOtherOperations

numberOfEvents

long numberOfEvents

Class com.hazelcast.impl.LocalQueueStatsImpl extends Object implements Serializable

Serialized Fields

ownedItemCount

int ownedItemCount

backupItemCount

int backupItemCount

minAge

long minAge

maxAge

long maxAge

aveAge

long aveAge

queueOperationStats

LocalQueueOperationStats queueOperationStats

Class com.hazelcast.impl.LocalTopicOperationStatsImpl extends Object implements Serializable

Serialized Fields

periodStart

long periodStart

periodEnd

long periodEnd

numberOfPublishes

long numberOfPublishes

numberOfReceives

long numberOfReceives

Class com.hazelcast.impl.LocalTopicStatsImpl extends Object implements Serializable

Serialized Fields

operationsStats

LocalTopicOperationStats operationsStats

Class com.hazelcast.impl.MapOperationStatsImpl extends Object implements Serializable

Serialized Fields

periodStart

long periodStart

periodEnd

long periodEnd

gets

com.hazelcast.impl.MapOperationStatsImpl.OperationStat gets

puts

com.hazelcast.impl.MapOperationStatsImpl.OperationStat puts

removes

com.hazelcast.impl.MapOperationStatsImpl.OperationStat removes

numberOfOtherOperations

long numberOfOtherOperations

numberOfEvents

long numberOfEvents

Class com.hazelcast.impl.MemberHealthStatsImpl extends Object implements Serializable

Serialized Fields

outOfMemory

boolean outOfMemory

active

boolean active

serviceThreadStats

ThreadStats serviceThreadStats

inThreadStats

ThreadStats inThreadStats

outThreadStats

ThreadStats outThreadStats

Class com.hazelcast.impl.MemberImpl extends Object implements Serializable

Serialization Methods

readObject

private void readObject(ObjectInputStream in)
                 throws IOException,
                        ClassNotFoundException
Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream out)
                  throws IOException
Throws:
IOException
Serialized Fields

localMember

boolean localMember

address

Address address

nodeType

NodeType nodeType

Class com.hazelcast.impl.MemberStateImpl extends Object implements Serializable

serialVersionUID: -1817978625085375340L

Serialized Fields

address

Address address

memberHealthStats

MemberHealthStatsImpl memberHealthStats

mapStats

Map<K,V> mapStats

queueStats

Map<K,V> queueStats

topicStats

Map<K,V> topicStats

lsPartitions

List<E> lsPartitions

Class com.hazelcast.impl.SemaphoreImpl extends com.hazelcast.impl.base.FactoryAwareNamedProxy implements Serializable

Serialized Fields

base

Semaphore base

nameAsData

Data nameAsData

Class com.hazelcast.impl.TestUtil.AbstractValue extends Object implements Serializable

Serialized Fields

name

String name

Class com.hazelcast.impl.TestUtil.Employee extends Object implements Serializable

Serialized Fields

id

long id

name

String name

city

String city

age

int age

active

boolean active

salary

double salary

Class com.hazelcast.impl.TestUtil.Value extends TestUtil.AbstractValue implements Serializable

Serialized Fields

type

TestUtil.ValueType type

index

int index

Class com.hazelcast.impl.TestUtil.ValueType extends Object implements Serializable

Serialized Fields

typeName

String typeName

Package com.hazelcast.logging

Class com.hazelcast.logging.LogEvent extends EventObject implements Serializable

Serialized Fields

logRecord

LogRecord logRecord

member

Member member

groupName

String groupName

Package com.hazelcast.monitor

Class com.hazelcast.monitor.ClusterStateViewImpl extends Object implements Serializable

Serialized Fields

memberPartitions

Map<K,V> memberPartitions

instanceNames

Set<E> instanceNames

Class com.hazelcast.monitor.DistributedMapStatsCallable extends Object implements Serializable

Serialized Fields

mapName

String mapName

Class com.hazelcast.monitor.DistributedMapStatsCallable.MemberMapStat extends Object implements Serializable

Serialized Fields

member

Member member

localMapStats

LocalMapStats localMapStats

Class com.hazelcast.monitor.DistributedMemberInfoCallable extends Object implements Serializable

Class com.hazelcast.monitor.DistributedMemberInfoCallable.MemberInfo extends Object implements Serializable

Serialized Fields

partitions

Set<E> partitions

time

long time

totalMemory

long totalMemory

freeMemory

long freeMemory

maxMemory

long maxMemory

availableProcessors

int availableProcessors

systemProps

Properties systemProps

Class com.hazelcast.monitor.DistributedQueueStatsCallable extends Object implements Serializable

Serialized Fields

qName

String qName

Class com.hazelcast.monitor.DistributedQueueStatsCallable.MemberQueueStats extends Object implements Serializable

Serialized Fields

member

Member member

localQueueStats

LocalQueueStats localQueueStats

Class com.hazelcast.monitor.TimedClusterState extends Object implements Serializable

Serialized Fields

time

long time

lsMemberStates

List<E> lsMemberStates

instanceNames

Set<E> instanceNames

Package com.hazelcast.nio

Class com.hazelcast.nio.AbstractEvolvableDataSerializable extends Object implements Serializable

Serialized Fields

futureData

byte[] futureData

Class com.hazelcast.nio.Address extends Object implements Serializable

serialVersionUID: -7626390274220424603L

Serialization Methods

readObject

public void readObject(ByteBuffer buffer)

writeObject

public void writeObject(ByteBuffer buffer)
Serialized Fields

host

String host

ip

byte[] ip

port

int port

hash

int hash

thisAddress

boolean thisAddress

Class com.hazelcast.nio.Data extends Object implements Serializable

Serialized Fields

buffer

byte[] buffer

Package com.hazelcast.partition

Class com.hazelcast.partition.MigrationEvent extends EventObject implements Serializable

Serialized Fields

partitionId

int partitionId

oldOwner

Member oldOwner

newOwner

Member newOwner

Package com.hazelcast.query

Class com.hazelcast.query.EntryKeyObject extends Object implements Serializable

Class com.hazelcast.query.PredicateBuilder extends Object implements Serializable

Serialized Fields

exp

Expression<T> exp

lsPredicates

List<E> lsPredicates

Class com.hazelcast.query.Predicates.AbstractExpression extends SerializationHelper implements Serializable

Class com.hazelcast.query.Predicates.AbstractPredicate extends SerializationHelper implements Serializable

Class com.hazelcast.query.Predicates.AndOrPredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

predicates

Predicate<K,V>[] predicates

and

boolean and

Class com.hazelcast.query.Predicates.BetweenPredicate extends Predicates.EqualPredicate implements Serializable

Serialized Fields

to

Object to

fromConvertedValue

Comparable<T> fromConvertedValue

toConvertedValue

Comparable<T> toConvertedValue

Class com.hazelcast.query.Predicates.EqualPredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

first

Expression<T> first

second

Object second

convertedSecondValue

Object convertedSecondValue

secondIsExpression

boolean secondIsExpression

Class com.hazelcast.query.Predicates.GetExpressionImpl extends Predicates.AbstractExpression implements Serializable

Serialized Fields

input

String input

ls

List<E> ls

Class com.hazelcast.query.Predicates.GreaterLessPredicate extends Predicates.EqualPredicate implements Serializable

Serialized Fields

equal

boolean equal

less

boolean less

Class com.hazelcast.query.Predicates.InPredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

first

Expression<T> first

inValueArray

Object[] inValueArray

inValues

Set<E> inValues

convertedInValues

Set<E> convertedInValues

firstValueObject

Object firstValueObject

Class com.hazelcast.query.Predicates.LikePredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

first

Expression<T> first

second

String second

pattern

Pattern pattern

Class com.hazelcast.query.Predicates.NotEqualPredicate extends Predicates.EqualPredicate implements Serializable

Class com.hazelcast.query.Predicates.NotPredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

predicate

Predicate<K,V> predicate

Class com.hazelcast.query.Predicates.RegexPredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

first

Expression<T> first

regex

String regex

pattern

Pattern pattern

Class com.hazelcast.query.SqlPredicate extends Predicates.AbstractPredicate implements Serializable

Serialized Fields

sql

String sql

Package com.hazelcast.util

Class com.hazelcast.util.ConcurrentHashSet extends AbstractSet<E> implements Serializable

Serialized Fields

m

Map<K,V> m

Class com.hazelcast.util.DistributedTimeoutException extends Object implements Serializable

Class com.hazelcast.util.SimpleImmutableEntry extends Object implements Serializable

serialVersionUID: 7138329143949025153L

Serialized Fields

key

Object key

value

Object value

Package com.hazelcast.util.concurrent

Class com.hazelcast.util.concurrent.ConcurrentSkipListMap extends AbstractMap<K,V> implements Serializable

serialVersionUID: -8627078645895051609L

Serialization Methods

readObject

private void readObject(ObjectInputStream s)
                 throws IOException,
                        ClassNotFoundException
Reconstitute the map from a stream.

Throws:
IOException
ClassNotFoundException

writeObject

private void writeObject(ObjectOutputStream s)
                  throws IOException
Save the state of this map to a stream.

Serial Data:
The key (Object) and value (Object) for each key-value mapping represented by the map, followed by null. The key-value mappings are emitted in key-order (as determined by the Comparator, or by the keys' natural ordering if no Comparator).
Throws:
IOException
Serialized Fields

comparator

Comparator<T> comparator
The comparator used to maintain order in this map, or null if using natural ordering.

 

Class com.hazelcast.util.concurrent.ConcurrentSkipListMap.SubMap extends AbstractMap<K,V> implements Serializable

serialVersionUID: -7647078645895051609L

Serialized Fields

m

ConcurrentSkipListMap<K,V> m
Underlying map


lo

Object lo
lower bound key, or null if from start


hi

Object hi
upper bound key, or null if to end


loInclusive

boolean loInclusive
inclusion flag for lo


hiInclusive

boolean hiInclusive
inclusion flag for hi


isDescending

boolean isDescending
direction

Class com.hazelcast.util.concurrent.ConcurrentSkipListSet extends AbstractSet<E> implements Serializable

serialVersionUID: -2479143111061671589L

Serialized Fields

m

ConcurrentNavigableMap<K,V> m
The underlying map. Uses Boolean.TRUE as value for each element. This field is declared final for the sake of thread safety, which entails some ugliness in clone()



Copyright © 2011 Hazel Bilisim Ltd.. All Rights Reserved.