Serialized Form
|
Package com.hazelcast.cluster |
conn
Connection conn
conn
Connection conn
address
Address address
add
boolean add
deadAddress
Address deadAddress
serialVersionUID: 4803635299019880729L
processables
List<E> processables
request
boolean request
memberCount
int memberCount
nodeType
NodeType nodeType
address
Address address
to
Address to
packetVersion
byte packetVersion
buildNumber
int buildNumber
config
Config config
address
Address address
- The address.
address
Address address
nodeType
NodeType nodeType
deadAddress
Address deadAddress
serialVersionUID: -2311579721761844861L
memberInfos
Collection<E> memberInfos
masterTime
long masterTime
connection
Connection connection
|
Package com.hazelcast.config |
enabled
boolean enabled
algorithm
String algorithm
keyPassword
String keyPassword
keyAlias
String keyAlias
storeType
String storeType
storePassword
String storePassword
storePath
String storePath
logger
ILogger logger
xmlConfig
String xmlConfig
groupConfig
GroupConfig groupConfig
port
int port
checkCompatibility
boolean checkCompatibility
reuseAddress
boolean reuseAddress
portAutoIncrement
boolean portAutoIncrement
executorConfig
ExecutorConfig executorConfig
mapExecutors
Map<K,V> mapExecutors
mapTopicConfigs
Map<K,V> mapTopicConfigs
mapQueueConfigs
Map<K,V> mapQueueConfigs
mapConfigs
Map<K,V> mapConfigs
configurationUrl
URL configurationUrl
configurationFile
File configurationFile
networkConfig
NetworkConfig networkConfig
superClient
boolean superClient
classLoader
ClassLoader classLoader
properties
Properties properties
mapMergePolicyConfigs
Map<K,V> mapMergePolicyConfigs
name
String name
corePoolSize
int corePoolSize
maxPoolSize
int maxPoolSize
keepAliveSeconds
int keepAliveSeconds
logger
ILogger logger
name
String name
password
String password
logger
ILogger logger
enabled
boolean enabled
interfaceSet
Set<E> interfaceSet
multicastConfig
MulticastConfig multicastConfig
tcpIpConfig
TcpIpConfig tcpIpConfig
name
String name
backupCount
int backupCount
evictionPercentage
int evictionPercentage
timeToLiveSeconds
int timeToLiveSeconds
maxIdleSeconds
int maxIdleSeconds
evictionDelaySeconds
int evictionDelaySeconds
maxSizeConfig
MaxSizeConfig maxSizeConfig
evictionPolicy
String evictionPolicy
valueIndexed
boolean valueIndexed
mapStoreConfig
MapStoreConfig mapStoreConfig
nearCacheConfig
NearCacheConfig nearCacheConfig
readBackupData
boolean readBackupData
cacheValue
boolean cacheValue
mergePolicy
String mergePolicy
size
int size
maxSizePolicy
String maxSizePolicy
enabled
boolean enabled
multicastGroup
String multicastGroup
multicastPort
int multicastPort
multicastTimeoutSeconds
int multicastTimeoutSeconds
interfaces
Interfaces interfaces
join
Join join
symmetricEncryptionConfig
SymmetricEncryptionConfig symmetricEncryptionConfig
asymmetricEncryptionConfig
AsymmetricEncryptionConfig asymmetricEncryptionConfig
name
String name
backingMapRef
String backingMapRef
maxSizePerJVM
int maxSizePerJVM
enabled
boolean enabled
salt
String salt
password
String password
iterationCount
int iterationCount
algorithm
String algorithm
key
byte[] key
connectionTimeoutSeconds
int connectionTimeoutSeconds
enabled
boolean enabled
members
List<E> members
requiredMember
String requiredMember
addresses
List<E> addresses
name
String name
globalOrderingEnabled
boolean globalOrderingEnabled
logger
ILogger logger
|
Package com.hazelcast.core |
serialVersionUID: -4L
task
Runnable task
result
Object result
serialVersionUID: -2296203982913729851L
entryEventType
EntryEventType entryEventType
key
Object key
oldValue
Object oldValue
value
Object value
member
Member member
name
String name
collection
boolean collection
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream out)
throws IOException
- Throws:
IOException
instanceEventType
InstanceEvent.InstanceEventType instanceEventType
instance
Instance instance
member
Member member
serialVersionUID: -2010865371829087371L
member
Member member
eventType
int eventType
|
Package com.hazelcast.examples |
year
int year
name
String name
field
byte[] field
input
String input
input
String input
|
Package com.hazelcast.impl |
base
AtomicNumber base
nameAsData
Data nameAsData
blockId
int blockId
owner
Address owner
migrationAddress
Address migrationAddress
hash
int hash
migrationStarted
boolean migrationStarted
hazelcast
HazelcastInstance hazelcast
item
Data item
name
String name
lsBlocks
List<E> lsBlocks
callable
Callable<V> callable
member
Member member
members
Set<E> members
key
Object key
partitionId
int partitionId
owner
MemberImpl owner
throwable
Throwable throwable
cost
long cost
expirationTime
long expirationTime
lastAccessTime
long lastAccessTime
lastUpdateTime
long lastUpdateTime
lastStoredTime
long lastStoredTime
creationTime
long creationTime
version
long version
hits
int hits
valid
boolean valid
name
String name
key
Object key
value
Object value
hazelcastInstance
HazelcastInstance hazelcastInstance
lsValues
Collection<E> lsValues
mapName
String mapName
keys
Keys keys
factory
FactoryImpl factory
mapName
String mapName
pairs
com.hazelcast.impl.base.Pairs pairs
factory
FactoryImpl factory
dataKey
Data dataKey
dataNewValue
Data dataNewValue
dataOldValue
Data dataOldValue
serialVersionUID: -8809741591882405286L
mapName
String mapName
percentage
int percentage
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream out)
throws IOException
- Throws:
IOException
name
String name
name
String name
key
Object key
name
String name
key
Object key
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream out)
throws IOException
- Throws:
IOException
name
String name
blockingQueueManager
BlockingQueueManager blockingQueueManager
listenerManager
ListenerManager listenerManager
topicManager
TopicManager topicManager
listenerManager
ListenerManager listenerManager
keys
Collection<E> keys
name
String name
key
Object key
listener
Object listener
includeValue
boolean includeValue
instanceType
Instance.InstanceType instanceType
localListener
boolean localListener
name
String name
factory
FactoryImpl factory
lastAccessTime
AtomicLong lastAccessTime
hits
AtomicLong hits
ownedEntryCount
long ownedEntryCount
backupEntryCount
long backupEntryCount
markedAsRemovedEntryCount
long markedAsRemovedEntryCount
ownedEntryMemoryCost
long ownedEntryMemoryCost
backupEntryMemoryCost
long backupEntryMemoryCost
markedAsRemovedMemoryCost
long markedAsRemovedMemoryCost
creationTime
long creationTime
lastUpdateTime
long lastUpdateTime
lastEvictionTime
long lastEvictionTime
lockedEntryCount
long lockedEntryCount
lockWaitCount
long lockWaitCount
dirtyEntryCount
long dirtyEntryCount
operationStats
LocalMapOperationStats operationStats
periodStart
long periodStart
periodEnd
long periodEnd
numberOfOffers
long numberOfOffers
numberOfRejectedOffers
long numberOfRejectedOffers
numberOfPolls
long numberOfPolls
numberOfEmptyPolls
long numberOfEmptyPolls
numberOfOtherOperations
long numberOfOtherOperations
numberOfEvents
long numberOfEvents
ownedItemCount
int ownedItemCount
backupItemCount
int backupItemCount
minAge
long minAge
maxAge
long maxAge
aveAge
long aveAge
queueOperationStats
LocalQueueOperationStats queueOperationStats
periodStart
long periodStart
periodEnd
long periodEnd
numberOfPublishes
long numberOfPublishes
numberOfReceives
long numberOfReceives
operationsStats
LocalTopicOperationStats operationsStats
periodStart
long periodStart
periodEnd
long periodEnd
gets
com.hazelcast.impl.MapOperationStatsImpl.OperationStat gets
puts
com.hazelcast.impl.MapOperationStatsImpl.OperationStat puts
removes
com.hazelcast.impl.MapOperationStatsImpl.OperationStat removes
numberOfOtherOperations
long numberOfOtherOperations
numberOfEvents
long numberOfEvents
outOfMemory
boolean outOfMemory
active
boolean active
serviceThreadStats
ThreadStats serviceThreadStats
inThreadStats
ThreadStats inThreadStats
outThreadStats
ThreadStats outThreadStats
readObject
private void readObject(ObjectInputStream in)
throws IOException,
ClassNotFoundException
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream out)
throws IOException
- Throws:
IOException
localMember
boolean localMember
address
Address address
nodeType
NodeType nodeType
serialVersionUID: -1817978625085375340L
address
Address address
memberHealthStats
MemberHealthStatsImpl memberHealthStats
mapStats
Map<K,V> mapStats
queueStats
Map<K,V> queueStats
topicStats
Map<K,V> topicStats
lsPartitions
List<E> lsPartitions
base
Semaphore base
nameAsData
Data nameAsData
name
String name
id
long id
name
String name
city
String city
age
int age
active
boolean active
salary
double salary
type
TestUtil.ValueType type
index
int index
typeName
String typeName
|
Package com.hazelcast.logging |
logRecord
LogRecord logRecord
member
Member member
groupName
String groupName
|
Package com.hazelcast.monitor |
memberPartitions
Map<K,V> memberPartitions
instanceNames
Set<E> instanceNames
mapName
String mapName
member
Member member
localMapStats
LocalMapStats localMapStats
partitions
Set<E> partitions
time
long time
totalMemory
long totalMemory
freeMemory
long freeMemory
maxMemory
long maxMemory
availableProcessors
int availableProcessors
systemProps
Properties systemProps
qName
String qName
member
Member member
localQueueStats
LocalQueueStats localQueueStats
time
long time
lsMemberStates
List<E> lsMemberStates
instanceNames
Set<E> instanceNames
|
Package com.hazelcast.nio |
futureData
byte[] futureData
serialVersionUID: -7626390274220424603L
readObject
public void readObject(ByteBuffer buffer)
writeObject
public void writeObject(ByteBuffer buffer)
host
String host
ip
byte[] ip
port
int port
hash
int hash
thisAddress
boolean thisAddress
buffer
byte[] buffer
|
Package com.hazelcast.partition |
partitionId
int partitionId
oldOwner
Member oldOwner
newOwner
Member newOwner
|
Package com.hazelcast.query |
exp
Expression<T> exp
lsPredicates
List<E> lsPredicates
predicates
Predicate<K,V>[] predicates
and
boolean and
to
Object to
fromConvertedValue
Comparable<T> fromConvertedValue
toConvertedValue
Comparable<T> toConvertedValue
first
Expression<T> first
second
Object second
convertedSecondValue
Object convertedSecondValue
secondIsExpression
boolean secondIsExpression
input
String input
ls
List<E> ls
equal
boolean equal
less
boolean less
first
Expression<T> first
inValueArray
Object[] inValueArray
inValues
Set<E> inValues
convertedInValues
Set<E> convertedInValues
firstValueObject
Object firstValueObject
first
Expression<T> first
second
String second
pattern
Pattern pattern
predicate
Predicate<K,V> predicate
first
Expression<T> first
regex
String regex
pattern
Pattern pattern
sql
String sql
|
Package com.hazelcast.util |
m
Map<K,V> m
serialVersionUID: 7138329143949025153L
key
Object key
value
Object value
|
Package com.hazelcast.util.concurrent |
serialVersionUID: -8627078645895051609L
readObject
private void readObject(ObjectInputStream s)
throws IOException,
ClassNotFoundException
- Reconstitute the map from a stream.
- Throws:
IOException
ClassNotFoundException
writeObject
private void writeObject(ObjectOutputStream s)
throws IOException
- Save the state of this map to a stream.
- Serial Data:
- The key (Object) and value (Object) for each
key-value mapping represented by the map, followed by
null. The key-value mappings are emitted in key-order
(as determined by the Comparator, or by the keys' natural
ordering if no Comparator).
- Throws:
IOException
comparator
Comparator<T> comparator
- The comparator used to maintain order in this map, or null
if using natural ordering.
-
|
Class com.hazelcast.util.concurrent.ConcurrentSkipListMap.SubMap extends AbstractMap<K,V> implements Serializable |
serialVersionUID: -7647078645895051609L
m
ConcurrentSkipListMap<K,V> m
- Underlying map
lo
Object lo
- lower bound key, or null if from start
hi
Object hi
- upper bound key, or null if to end
loInclusive
boolean loInclusive
- inclusion flag for lo
hiInclusive
boolean hiInclusive
- inclusion flag for hi
isDescending
boolean isDescending
- direction
serialVersionUID: -2479143111061671589L
m
ConcurrentNavigableMap<K,V> m
- The underlying map. Uses Boolean.TRUE as value for each
element. This field is declared final for the sake of thread
safety, which entails some ugliness in clone()
Copyright © 2011 Hazel Bilisim Ltd.. All Rights Reserved.